@@ -29,17 +29,31 @@ DEFAULT_CONFIG = {
         },
         # quill-image-resize
         "imageResize": {},
+        # quill-video-resize
+        "videoResize": {
+            "modules": ["Resize"],
+            "tagName": "iframe",
+        },
     },
 }
 MEDIA_JS = [
+    # syntax-highlight
     "https://cdnjs.cloudflare.com/ajax/libs/highlight.js/10.1.1/highlight.min.js",
+    # quill
     "https://cdn.quilljs.com/1.3.7/quill.min.js",
-    "https://unpkg.com/quill-image-compress@1.2.21/dist/quill.imageCompressor.min.js",
-    "https://cdn.jsdelivr.net/npm/quill-image-resize-module@3.0.0/image-resize.min.js",
+    # quill-image-compress
+    "https://cdn.jsdelivr.net/npm/quill-image-compress@1.2.21/dist/quill.imageCompressor.min.js",
+    # quill-resize
+    "https://cdn.jsdelivr.net/npm/@botom/quill-resize-module@2.0.0/dist/quill-resize-module.min.js",
+    # custom
     "django_quill/django_quill.js",
 ]
 MEDIA_CSS = [
+    # syntax-highlight
     "https://cdn.quilljs.com/1.3.7/quill.snow.css",
     "https://cdnjs.cloudflare.com/ajax/libs/highlight.js/10.1.1/styles/darcula.min.css",
+    # quill-resize
+    "https://cdn.jsdelivr.net/npm/quill-resize-module@1.2.4/dist/resize.min.css",
+    # custom
     "django_quill/django_quill.css",
 ]
